@@ -13,7 +13,7 @@
 #include <QtQml>
 
 #include <KConfigLoader>
-#include <KDeclarative/ConfigPropertyMap>
+#include <KConfigPropertyMap>
 #include <KDesktopFile>
 #include <KLocalizedString>
 #include <KPackage/PackageLoader>
@@ -220,7 +220,7 @@ QJsonArray SensorFaceControllerPrivate::readSensors(const KConfigGroup &read, co
     QJsonArray newSensors;
     for (auto entry : original) {
         QString sensorId = entry.toString();
-        for (auto replacement : qAsConst(sensorIdReplacements)) {
+        for (auto replacement : std::as_const(sensorIdReplacements)) {
             auto match = replacement.first.match(sensorId);
             if (match.hasMatch()) {
                 sensorId.replace(replacement.first, replacement.second);
@@ -686,7 +686,7 @@ QString SensorFaceController::faceId() const
     return d->faceId;
 }
 
-KDeclarative::ConfigPropertyMap *SensorFaceController::faceConfiguration() const
+KConfigPropertyMap *SensorFaceController::faceConfiguration() const
 {
     return d->faceConfiguration;
 }
@@ -996,9 +996,6 @@ bool SensorFaceController::shouldSync() const
 void SensorFaceController::setShouldSync(bool sync)
 {
     d->shouldSync = sync;
-    if (d->faceConfiguration) {
-        d->faceConfiguration->setAutosave(sync);
-    }
     if (!d->shouldSync && d->syncTimer->isActive()) {
         d->syncTimer->stop();
     }
@@ -1021,9 +1018,8 @@ void SensorFaceController::reloadFaceConfiguration()
         }
 
         d->faceConfigLoader = new KConfigLoader(cg, &file, this);
-        d->faceConfiguration = new KDeclarative::ConfigPropertyMap(d->faceConfigLoader, this);
-        d->faceConfiguration->setAutosave(d->shouldSync);
-        connect(d->faceConfiguration, &KDeclarative::ConfigPropertyMap::valueChanged, this, [this](const QString &key) {
+        d->faceConfiguration = new KConfigPropertyMap(d->faceConfigLoader, this);
+        connect(d->faceConfiguration, &KConfigPropertyMap::valueChanged, this, [this](const QString &key) {
             auto item = d->faceConfigLoader->findItemByName(key);
             if (item) {
                 item->writeConfig(d->faceConfigLoader->config());
