@@ -523,7 +523,7 @@ ExtendedProcesses::ExtendedProcesses(QObject *parent)
     });
 
     connect(this, &KSysGuard::Processes::updated, this, [this]() {
-        for (auto p : qAsConst(d->m_providers)) {
+        for (auto p : std::as_const(d->m_providers)) {
             if (p->enabled()) {
                 p->update();
             }
@@ -543,7 +543,7 @@ QVector<ProcessAttribute *> ExtendedProcesses::attributes() const
 QVector<ProcessAttribute *> ExtendedProcesses::extendedAttributes() const
 {
     QVector<ProcessAttribute *> rc;
-    for (auto p : qAsConst(d->m_providers)) {
+    for (auto p : std::as_const(d->m_providers)) {
         rc << p->attributes();
     }
     return rc;
@@ -555,17 +555,12 @@ void ExtendedProcesses::Private::loadPlugins()
     // instantiate all plugins
     for (const auto &pluginMetaData : listMetaData) {
         qCDebug(LIBKSYSGUARD_PROCESSCORE) << "loading plugin" << pluginMetaData.name();
-        auto factory = qobject_cast<KPluginFactory *>(pluginMetaData.instantiate());
-        if (!factory) {
-            qCCritical(LIBKSYSGUARD_PROCESSCORE) << "failed to load plugin factory" << pluginMetaData.name();
-            continue;
-        }
-        ProcessDataProvider *provider = factory->create<ProcessDataProvider>(q);
-        if (!provider) {
+        auto provider = KPluginFactory::instantiatePlugin<ProcessDataProvider>(pluginMetaData, q);
+        if (!provider.plugin) {
             qCCritical(LIBKSYSGUARD_PROCESSCORE) << "failed to instantiate ProcessDataProvider" << pluginMetaData.name();
             continue;
         }
-        m_providers << provider;
+        m_providers << provider.plugin;
     }
 }
 
